@@ -1,19 +1,25 @@
 import time
 import boto3
 
-from warrant import AWSSRP
 import streamlit as st
 import extra_streamlit_components as stx
 
 from .exceptions import TokenVerificationException
 from .utils import verify_access_token
 
+import pycognito
+from pycognito import AWSSRP
+
 
 class CognitoAuthenticator:
-    def __init__(self, pool_id, app_client_id, app_client_secret, boto_client=None):
-        self.client = boto_client or boto3.client("cognito-idp")
-        self.pool_id = pool_id
+    def __init__(
+        self, pool_id, app_client_id, app_client_secret=None, boto_client=None
+    ):
         self.pool_region = pool_id.split("_")[0]
+        self.client = boto_client or boto3.client(
+            "cognito-idp", region_name=self.pool_region
+        )
+        self.pool_id = pool_id
         self.app_client_id = app_client_id
         self.app_client_secret = app_client_secret
 
@@ -95,41 +101,31 @@ class CognitoAuthenticator:
         )
 
     def _login(self, username, password):
-        aws_srp = AWSSRP(
-            client=self.client,
-            pool_id=self.pool_id,
-            client_id=self.app_client_id,
-            client_secret=self.app_client_secret,
-            username=username,
-            password=password,
-        )
-        auth_params = aws_srp.get_auth_params()
-        response = self.client.initiate_auth(
-            AuthFlow="USER_SRP_AUTH",
-            AuthParameters=auth_params,
-            ClientId=aws_srp.client_id,
-        )
-        if response["ChallengeName"] != aws_srp.PASSWORD_VERIFIER_CHALLENGE:
-            raise NotImplementedError(
-                f"The {response['ChallengeName']} challenge is not supported"
-            )
+        aws_srp_args = {
+            "client": self.client,
+            "pool_id": self.pool_id,
+            "client_id": self.app_client_id,
+            "username": username,
+            "password": password,
+        }
 
-        challenge_response = aws_srp.process_challenge(response["ChallengeParameters"])
+        if self.app_client_secret is not None:
+            aws_srp_args["client_secret"] = self.app_client_secret
+
+        aws_srp = AWSSRP(**aws_srp_args)
         try:
-            tokens = self.client.respond_to_auth_challenge(
-                ClientId=aws_srp.client_id,
-                ChallengeName=aws_srp.PASSWORD_VERIFIER_CHALLENGE,
-                ChallengeResponses=challenge_response,
-            )
-
-            # new password required
-            if tokens.get("ChallengeName") == aws_srp.NEW_PASSWORD_REQUIRED_CHALLENGE:
-                self._set_reset_password_temp(tokens["Session"], username, password)
-                return False
-
+            tokens = aws_srp.authenticate_user()
             self._set_auth_cookies(tokens)
             return True
 
+        except pycognito.exceptions.ForceChangePasswordException as e:
+            self._set_reset_password_temp("x", username, password)
+            return False
+
+        except self.client.exceptions.PasswordResetRequiredException as e:
+            self._reset_session_state()
+            return False
+
         except self.client.exceptions.NotAuthorizedException as e:
             self._reset_session_state()
             return False
@@ -144,39 +140,20 @@ class CognitoAuthenticator:
         password,
         new_password,
     ):
-        aws_srp = AWSSRP(
-            client=self.client,
-            pool_id=self.pool_id,
-            client_id=self.app_client_id,
-            client_secret=self.app_client_secret,
-            username=username,
-            password=password,
-        )
-        challenge_response = {
-            "USERNAME": username,
-            "NEW_PASSWORD": new_password,
+        aws_srp_args = {
+            "client": self.client,
+            "pool_id": self.pool_id,
+            "client_id": self.app_client_id,
+            "username": username,
+            "password": password,
         }
 
-        # warrant lib does not support reset password with client secret app client
-        if aws_srp.client_secret is not None:
-            challenge_response.update(
-                {
-                    "SECRET_HASH": aws_srp.get_secret_hash(
-                        aws_srp.username,
-                        aws_srp.client_id,
-                        aws_srp.client_secret,
-                    )
-                }
-            )
+        if self.app_client_secret is not None:
+            aws_srp_args["client_secret"] = self.app_client_secret
 
-        reset_password_session = st.session_state["auth_reset_password_session"]
+        aws_srp = AWSSRP(**aws_srp_args)
         try:
-            tokens = self.client.respond_to_auth_challenge(
-                ClientId=aws_srp.client_id,
-                ChallengeName=aws_srp.NEW_PASSWORD_REQUIRED_CHALLENGE,
-                Session=reset_password_session,
-                ChallengeResponses=challenge_response,
-            )
+            tokens = aws_srp.set_new_password_challenge(new_password=new_password)
             self._set_auth_cookies(tokens)
             self._clear_reset_password_temp()
             return True
@@ -203,6 +180,7 @@ class CognitoAuthenticator:
                         "Password",
                         type="password",
                         value=st.session_state["auth_reset_password_password"],
+                        disabled=True,
                     )
                     new_password = st.text_input("New Password", type="password")
                     confirm_new_password = st.text_input(
